@@ -497,7 +497,7 @@ export class CommandRegistry {
    */
   processKeydownEvent(event: KeyboardEvent): void {
     // Bail immediately if playing back keystrokes.
-    if (this._replaying) {
+    if (this._replaying || CommandRegistry.isModifierKeyPressed(event)) {
       return;
     }
 
@@ -1062,6 +1062,26 @@ export namespace CommandRegistry {
      */
     shift: boolean;
 
+    /**
+     * Whether `'ArrowLeft'` appears in the keystroke.
+     */
+    arrowLeft: boolean;
+
+    /**
+     * Whether `'ArrowUp'` appears in the keystroke.
+     */
+    arrowUp: boolean;
+
+    /**
+     * Whether `'ArrowRight'` appears in the keystroke.
+     */
+    arrowRight: boolean;
+
+    /**
+     * Whether `'ArrowDown'` appears in the keystroke.
+     */
+    arrowDown: boolean;
+
     /**
      * The primary key for the keystroke.
      */
@@ -1096,6 +1116,10 @@ export namespace CommandRegistry {
     let cmd = false;
     let ctrl = false;
     let shift = false;
+    let arrowLeft = false;
+    let arrowUp = false;
+    let arrowRight = false;
+    let arrowDown = false;
     for (let token of keystroke.split(/\s+/)) {
       if (token === 'Accel') {
         if (Platform.IS_MAC) {
@@ -1111,11 +1135,29 @@ export namespace CommandRegistry {
         ctrl = true;
       } else if (token === 'Shift') {
         shift = true;
+      } else if (token === 'ArrowLeft') {
+        arrowLeft = true;
+      } else if (token === 'ArrowUp') {
+        arrowUp = true;
+      } else if (token === 'ArrowRight') {
+        arrowRight = true;
+      } else if (token === 'ArrowDown') {
+        arrowDown = true;
       } else if (token.length > 0) {
         key = token;
       }
     }
-    return { cmd, ctrl, alt, shift, key };
+    return {
+      cmd,
+      ctrl,
+      alt,
+      shift,
+      key,
+      arrowLeft,
+      arrowUp,
+      arrowRight,
+      arrowDown
+    };
   }
 
   /**
@@ -1187,6 +1229,18 @@ export namespace CommandRegistry {
       if (parts.cmd) {
         mods += '\u2318 ';
       }
+      if (parts.arrowLeft) {
+        mods += '\u2190 ';
+      }
+      if (parts.arrowUp) {
+        mods += '\u2191 ';
+      }
+      if (parts.arrowRight) {
+        mods += '\u2192 ';
+      }
+      if (parts.arrowDown) {
+        mods += '\u2193 ';
+      }
     } else {
       if (parts.ctrl) {
         mods += 'Ctrl+';
@@ -1201,6 +1255,19 @@ export namespace CommandRegistry {
     return mods + parts.key;
   }
 
+  /**
+   * Check if `'keydown'` event is caused by pressing a modifier key that should be ignored.
+   *
+   * @param event - The event object for a `'keydown'` event.
+   *
+   * @returns `true` if modifier key was pressed, `false` otherwise.
+   */
+  export function isModifierKeyPressed(event: KeyboardEvent): boolean {
+    let layout = getKeyboardLayout();
+    let key = layout.keyForKeydownEvent(event);
+    return layout.isModifierKey(key);
+  }
+
   /**
    * Create a normalized keystroke for a `'keydown'` event.
    *
@@ -1210,8 +1277,9 @@ export namespace CommandRegistry {
    *   does not represent a valid keystroke for the given layout.
    */
   export function keystrokeForKeydownEvent(event: KeyboardEvent): string {
-    let key = getKeyboardLayout().keyForKeydownEvent(event);
-    if (!key) {
+    let layout = getKeyboardLayout();
+    let key = layout.keyForKeydownEvent(event);
+    if (!key || layout.isModifierKey(key)) {
       return '';
     }
     let mods = '';
